@@ -1,10 +1,10 @@
-# Copyright (c) 2003-2014 CORE Security Technologies
+# Copyright (c) 2003-2016 CORE Security Technologies
 #
 # This software is provided under under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
 # for more information.
 #
-# Author: Alberto Solino (bethus@gmail.com, @agsolino)
+# Author: Alberto Solino (@agsolino)
 #
 # Description:
 #   Kerberos Credential Cache format implementation
@@ -14,15 +14,15 @@
 #   Contribution is welcome to make it the right way
 #
 
-import sys
 from datetime import datetime
 from struct import pack, unpack, calcsize
-from impacket.winregistry import hexdump
+
+from pyasn1.codec.der import decoder, encoder
+from binascii import hexlify
+
 from impacket.structure import Structure
 from impacket.krb5 import crypto, constants, types
-from impacket.krb5.asn1 import AS_REP, seq_set, EncryptedData, TGS_REP, EncTGSRepPart, EncASRepPart, Ticket
-from pyasn1.codec.der import decoder, encoder
-
+from impacket.krb5.asn1 import AS_REP, seq_set, TGS_REP, EncTGSRepPart, EncASRepPart, Ticket
 
 DELTA_TIME = 1
 
@@ -48,7 +48,7 @@ class CountedOctetString(Structure):
     )
 
     def prettyPrint(self, indent=''):
-        return "%s%s" % (indent, self['data'].encode('hex'))
+        return "%s%s" % (indent, hexlify(self['data']))
 
 class KeyBlock(Structure):
     structure = (
@@ -60,7 +60,7 @@ class KeyBlock(Structure):
     )
 
     def prettyPrint(self):
-        return "Key: (0x%x)%s" % (self['keytype'], self['keyvalue'].encode('hex'))
+        return "Key: (0x%x)%s" % (self['keytype'], hexlify(self['keyvalue']))
 
 class Times(Structure):
     structure = (
@@ -87,15 +87,15 @@ class AuthData(Structure):
         ('authdata',':', CountedOctetString),
     )
 
-class Principal():
+class Principal:
     class PrincipalHeader(Structure):
         structure = (
             ('name_type','!L=0'),
             ('num_components','!L=0'),
         )
-    components = []
-    realm = None
     def __init__(self, data=None):
+        self.components = []
+        self.realm = None
         if data is not None:
             self.header = self.PrincipalHeader(data)
             data = data[len(self.header):]
@@ -150,7 +150,7 @@ class Principal():
     def toPrincipal(self):
         return types.Principal(self.prettyPrint(), type=self.header['name_type'])
 
-class Credential():
+class Credential:
     class CredentialHeader(Structure):
         structure = (
             ('client',':', Principal),
@@ -162,13 +162,13 @@ class Credential():
             ('num_address','!L=0'),
         )
 
-    addresses = ()
-    authData = ()
-    header = None
-    ticket = None
-    secondTicket = None
- 
     def __init__(self, data=None):
+        self.addresses = ()
+        self.authData = ()
+        self.header = None
+        self.ticket = None
+        self.secondTicket = None
+
         if data is not None:
             self.header = self.CredentialHeader(data)
             data = data[len(self.header):]
@@ -290,11 +290,7 @@ class Credential():
         tgs['sessionKey'] = crypto.Key(cipher.enctype, str(self['key']['keyvalue']))
         return tgs
         
-class CCache():
-    headers = None
-    principal = None
-    credentials = []
-    miniHeader = None
+class CCache:
     class MiniHeader(Structure):
         structure = (
             ('file_format_version','!H=0x0504'),
@@ -302,6 +298,10 @@ class CCache():
         )
 
     def __init__(self, data = None):
+        self.headers = None
+        self.principal = None
+        self.credentials = []
+        self.miniHeader = None
         if data is not None:
             miniHeader = self.MiniHeader(data)
             data = data[len(str(miniHeader)):]
