@@ -1,10 +1,10 @@
-# Copyright (c) 2003-2012 CORE Security Technologies)
+# Copyright (c) 2003-2016 CORE Security Technologies
 #
 # This software is provided under under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
 # for more information.
 #
-# Author: Alberto Solino (beto@coresecurity.com)
+# Author: Alberto Solino (@agsolino)
 #
 # Description:
 #   SMB 2 and 3 Protocol Structures and constants [MS-SMB2]
@@ -398,8 +398,6 @@ SMB2_FILESYSTEM_ATTRIBUTE_INFO        = 5
 SMB2_FILESYSTEM_CONTROL_INFO          = 6
 SMB2_FILESYSTEM_FULL_SIZE_INFO        = 7
 SMB2_FILESYSTEM_OBJECT_ID_INFO        = 8
-SMB2_FILESYSTEM_OBJECT_ID_INFO        = 8
-SMB2_FILESYSTEM_OBJECT_ID_INFO        = 8
 SMB2_FILESYSTEM_DRIVER_PATH_INFO      = 9
 SMB2_FILESYSTEM_SECTOR_SIZE_INFO      = 11
 
