@@ -1038,6 +1038,8 @@ def main():
    machine.run()
 
 if __name__ == '__main__':
+   # Init the example's logger theme
+   logger.init()
    main()
 
 # All Probes
@@ -1121,5 +1123,5 @@ if __name__ == '__main__':
 # [-] ??? (TOS) Type of Service
 # [-] ??? (RUL) Length of return UDP packet is correct
 
-# sudo nmap -O 127.0.0.2 -p 22,111,89
-# sudo /usr/local/bin/python2.7 nmapAnswerMachine.py -i em0 -p 192.168.66.254 -f 'Sun Solaris 9 (SPARC)'
+# doas nmap -O 127.0.0.2 -p 22,111,89
+# doas /usr/local/bin/python2.7 nmapAnswerMachine.py -i em0 -p 192.168.66.254 -f 'Sun Solaris 9 (SPARC)'
