@@ -66,14 +66,16 @@ class WMIPERSISTENCE:
         if options.hashes is not None:
             self.__lmhash, self.__nthash = options.hashes.split(':')
 
-    def checkError(self, banner, resp):
+    @staticmethod
+    def checkError(banner, resp):
         if resp.GetCallStatus(0) != 0:
             logging.error('%s - ERROR (0x%x)' % (banner, resp.GetCallStatus(0)))
         else:
             logging.info('%s - OK' % banner)
 
     def run(self, addr):
-        dcom = DCOMConnection(addr, self.__username, self.__password, self.__domain, self.__lmhash, self.__nthash, options.aesKey, oxidResolver = False, doKerberos=options.k)
+        dcom = DCOMConnection(addr, self.__username, self.__password, self.__domain, self.__lmhash, self.__nthash,
+                              options.aesKey, oxidResolver=False, doKerberos=options.k, kdcHost=options.dc_ip)
 
         iInterface = dcom.CoCreateInstanceEx(wmi.CLSID_WbemLevel1Login,wmi.IID_IWbemLevel1Login)
         iWbemLevel1Login = wmi.IWbemLevel1Login(iInterface)
@@ -81,17 +83,20 @@ class WMIPERSISTENCE:
         iWbemLevel1Login.RemRelease()
 
         if self.__options.action.upper() == 'REMOVE':
-            self.checkError( 'Removing ActiveScriptEventConsumer %s'% self.__options.name, 
-                  iWbemServices.DeleteInstance('ActiveScriptEventConsumer.Name="%s"' % self.__options.name))
+            self.checkError('Removing ActiveScriptEventConsumer %s' % self.__options.name,
+                            iWbemServices.DeleteInstance('ActiveScriptEventConsumer.Name="%s"' % self.__options.name))
 
-            self.checkError( 'Removing EventFilter EF_%s'% self.__options.name,
-                  iWbemServices.DeleteInstance('__EventFilter.Name="EF_%s"'% self.__options.name))
+            self.checkError('Removing EventFilter EF_%s' % self.__options.name,
+                            iWbemServices.DeleteInstance('__EventFilter.Name="EF_%s"' % self.__options.name))
 
-            self.checkError( 'Removing IntervalTimerInstruction TI_%s'% self.__options.name,
-                  iWbemServices.DeleteInstance('__IntervalTimerInstruction.TimerId="TI_%s"'% self.__options.name))
+            self.checkError('Removing IntervalTimerInstruction TI_%s' % self.__options.name,
+                            iWbemServices.DeleteInstance(
+                                '__IntervalTimerInstruction.TimerId="TI_%s"' % self.__options.name))
 
-            self.checkError( 'Removing FilterToConsumerBinding %s'% self.__options.name,
-                  iWbemServices.DeleteInstance(r'__FilterToConsumerBinding.Consumer="ActiveScriptEventConsumer.Name=\"%s\"",Filter="__EventFilter.Name=\"EF_%s\""' % (self.__options.name, self.__options.name)))
+            self.checkError('Removing FilterToConsumerBinding %s' % self.__options.name,
+                            iWbemServices.DeleteInstance(
+                                r'__FilterToConsumerBinding.Consumer="ActiveScriptEventConsumer.Name=\"%s\"",Filter="__EventFilter.Name=\"EF_%s\""' % (
+                                self.__options.name, self.__options.name)))
         else:
             activeScript ,_ = iWbemServices.GetObject('ActiveScriptEventConsumer')
             activeScript =  activeScript.SpawnInstance()
@@ -172,6 +177,7 @@ if __name__ == '__main__':
     group.add_argument('-no-pass', action="store_true", help='don\'t ask for password (useful for -k)')
     group.add_argument('-k', action="store_true", help='Use Kerberos authentication. Grabs credentials from ccache file (KRB5CCNAME) based on target parameters. If valid credentials cannot be found, it will use the ones specified in the command line')
     group.add_argument('-aesKey', action="store", metavar = "hex key", help='AES key to use for Kerberos Authentication (128 or 256 bits)')
+    group.add_argument('-dc-ip', action='store',metavar = "ip address",  help='IP Address of the domain controller. If ommited it use the domain part (FQDN) specified in the target parameter')
  
     if len(sys.argv)==1:
         parser.print_help()
@@ -192,7 +198,9 @@ if __name__ == '__main__':
             sys.exit(1)
 
     import re
-    domain, username, password, address = re.compile('(?:(?:([^/@:]*)/)?([^@:]*)(?::([^@]*))?@)?(.*)').match(options.target).groups('')
+
+    domain, username, password, address = re.compile('(?:(?:([^/@:]*)/)?([^@:]*)(?::([^@]*))?@)?(.*)').match(
+        options.target).groups('')
 
     #In case the password contains '@'
     if '@' in address:
